@@ -93,50 +93,52 @@ class Iserv(BaseIserv):
         self._login()
         return self.session.get(f"{self.url}/iserv")
 
-    def get_untis_substitution_plan(self, path, schoolclass):
+    def get_untis_substitution_plan(self, path, courses):
         """
         Gets untis substitution plan data for a given class.
         """
-        headers = {'User-Agent': 'Mozilla/5.0'}
-        payload = {'_username': self.username, '_password': self.password}
-        self.session.post(self.url + '/iserv/login_check', headers=headers, data=payload)
+        # self.session.post(self.url + '/iserv/login_check', headers=headers, data=payload)
+        self._login()
         res = self.session.get(self.url + path)
         plan_soup = BeautifulSoup(res.text, 'lxml')
-        rows = []
-        for row in plan_soup.find_all('tr', class_='list'):
-            pattern = Template('(.*|^)$number.*$char.*$')
-            rowlist = []
-            for i in row:
-                rowlist.append(i.text)
-            if len(rowlist) < 2:
-                continue
-            currentclass = rowlist[4].strip()
-            patternresult = re.search(pattern.safe_substitute(number=schoolclass[0], char=schoolclass[1]), currentclass)
-            if patternresult and currentclass[0] in numbers or currentclass == schoolclass:
-                text = []
-                for cell in row.find_all('td'):
-                    if schoolclass not in cell.text and cell.text.isspace() is not True:
-                        temptext = ""
-                        for test in cell.children:
-                            try:
-                                for test2 in test.children:
-                                    temptext = temptext + str(test2)
-                            except AttributeError:
-                                temptext = temptext + test
-                        text.append(temptext)
-                rows.append(text)
-            rows = list(filter(lambda x: x, rows))
-        rows = remove_duplicates(i if isinstance(i, list) else i for i in remove_duplicates(rows))
+        rows_collection = {}
+        for schoolclass in courses:
+            rows = []
+            for row in plan_soup.find_all('tr', class_='list'):
+                pattern = Template('(.*|^)$number.*$char.*$')
+                rowlist = []
+                for i in row:
+                    rowlist.append(i.text)
+                if len(rowlist) < 2:
+                    continue
+                currentclass = rowlist[4].strip()
+                patternresult = re.search(pattern.safe_substitute(number=schoolclass[0], char=schoolclass[1]),
+                                          currentclass)
+                if patternresult and currentclass[0] in numbers or currentclass == schoolclass:
+                    text = []
+                    for cell in row.find_all('td'):
+                        if schoolclass not in cell.text and cell.text.isspace() is not True:
+                            temptext = ""
+                            for test in cell.children:
+                                try:
+                                    for test2 in test.children:
+                                        temptext = temptext + str(test2)
+                                except AttributeError:
+                                    temptext = temptext + test
+                            text.append(temptext)
+                    rows.append(text)
+                rows = list(filter(lambda x: x, rows))
+            rows_collection[schoolclass] = remove_duplicates(
+                i if isinstance(i, list) else i for i in remove_duplicates(rows))
         date = plan_soup.find('div', class_="mon_title").text.split(" ")[0]
-        return rows, date
+        week = plan_soup.find('div', class_="mon_title").text.split(" ")[-1]
+        return rows_collection, date, week
 
     def get_next_tests_formatted(self, path="/iserv"):
         """
         Same as get_next_tests() but does not parse the data, just gives a string per test, not a dict
         """
-        headers = {'User-Agent': 'Mozilla/5.0'}
-        payload = {'_username': self.username, '_password': self.password}
-        self.session.post(self.url + '/iserv/login_check', headers=headers, data=payload)
+        self._login()
 
         test_list = []
 
